==> python-frontend-2.1.0.5269-sources.jar: org/sonar/python/tree/FileInputImpl.java <==
/*
 * SonarQube Python Plugin
 * Copyright (C) 2011-2019 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.python.tree;

import java.util.HashSet;
import java.util.List;
import java.util.Objects;
import java.util.Set;
import java.util.stream.Collectors;
import java.util.stream.Stream;
import javax.annotation.CheckForNull;
import javax.annotation.Nullable;
import org.sonar.plugins.python.api.tree.FileInput;
import org.sonar.plugins.python.api.tree.StatementList;
import org.sonar.plugins.python.api.tree.StringLiteral;
import org.sonar.plugins.python.api.tree.Token;
import org.sonar.plugins.python.api.tree.Tree;
import org.sonar.plugins.python.api.tree.TreeVisitor;
import org.sonar.python.semantic.Symbol;

public class FileInputImpl extends PyTree implements FileInput {

  private final StatementList statements;
  private final Token endOfFile;
  private final StringLiteral docstring;
  private final Set<Symbol> globalVariables = new HashSet<>();

  public FileInputImpl(@Nullable StatementList statements, Token endOfFile, @Nullable StringLiteral docstring) {
    this.statements = statements;
    this.endOfFile = endOfFile;
    this.docstring = docstring;
  }

  @Override
  public Kind getKind() {
    return Tree.Kind.FILE_INPUT;
  }

  @Override
  @CheckForNull
  public StatementList statements() {
    return statements;
  }

  @CheckForNull
  @Override
  public StringLiteral docstring() {
    return docstring;
  }

  @Override
  public Set<Symbol> globalVariables() {
    return globalVariables;
  }

  public void addGlobalVariables(Symbol globalVariable) {
    globalVariables.add(globalVariable);
  }

  @Override
  public void accept(TreeVisitor visitor) {
    visitor.visitFileInput(this);
  }

  @Override
  public List<Tree> computeChildren() {
    return Stream.of(statements, endOfFile).filter(Objects::nonNull).collect(Collectors.toList());
  }
}

==> python-frontend-2.2.0.5331-sources.jar: org/sonar/python/tree/FileInputImpl.java <==
/*
 * SonarQube Python Plugin
 * Copyright (C) 2011-2019 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.python.tree;

import java.util.HashSet;
import java.util.List;
import java.util.Objects;
import java.util.Set;
import java.util.stream.Collectors;
import java.util.stream.Stream;
import javax.annotation.CheckForNull;
import javax.annotation.Nullable;
import org.sonar.plugins.python.api.tree.FileInput;
import org.sonar.plugins.python.api.tree.StatementList;
import org.sonar.plugins.python.api.tree.StringLiteral;
import org.sonar.plugins.python.api.tree.Token;
import org.sonar.plugins.python.api.tree.Tree;
import org.sonar.plugins.python.api.tree.TreeVisitor;
import org.sonar.plugins.python.api.symbols.Symbol;

public class FileInputImpl extends PyTree implements FileInput {

  private final StatementList statements;
  private final Token endOfFile;
  private final StringLiteral docstring;
  private final Set<Symbol> globalVariables = new HashSet<>();

  public FileInputImpl(@Nullable StatementList statements, Token endOfFile, @Nullable StringLiteral docstring) {
    this.statements = statements;
    this.endOfFile = endOfFile;
    this.docstring = docstring;
  }

  @Override
  public Kind getKind() {
    return Tree.Kind.FILE_INPUT;
  }

  @Override
  @CheckForNull
  public StatementList statements() {
    return statements;
  }

  @CheckForNull
  @Override
  public StringLiteral docstring() {
    return docstring;
  }

  @Override
  public Set<Symbol> globalVariables() {
    return globalVariables;
  }

  public void addGlobalVariables(Symbol globalVariable) {
    globalVariables.add(globalVariable);
  }

  @Override
  public void accept(TreeVisitor visitor) {
    visitor.visitFileInput(this);
  }

  @Override
  public List<Tree> computeChildren() {
    return Stream.of(statements, endOfFile).filter(Objects::nonNull).collect(Collectors.toList());
  }
}
